@@ -57,6 +57,7 @@ import com.openexchange.imap.config.IMAPConfig;
 import com.openexchange.imap.ping.IMAPCapabilityAndGreetingCache;
 import com.openexchange.imap.util.HostAndPort;
 import com.openexchange.mail.MailExceptionCode;
+import com.openexchange.mailaccount.MailAccount;
 
 /**
  * {@link IMAPServerInfo} - IMAP server information.
@@ -76,7 +77,8 @@ public class IMAPServerInfo {
      */
     public static IMAPServerInfo instanceFor(IMAPConfig imapConfig, int accountId) throws OXException {
         try {
-            String greeting = IMAPCapabilityAndGreetingCache.getGreeting(new HostAndPort(IDNA.toASCII(imapConfig.getServer()), imapConfig.getPort()), imapConfig.isSecure(), imapConfig.getIMAPProperties());
+            boolean isPrimary = imapConfig.getAccountId() == MailAccount.DEFAULT_ID;
+            String greeting = IMAPCapabilityAndGreetingCache.getGreeting(new HostAndPort(IDNA.toASCII(imapConfig.getServer()), imapConfig.getPort()), imapConfig.isSecure(), imapConfig.getIMAPProperties(), isPrimary);
             Map<String, String> capabilities = imapConfig.asMap();
             return new IMAPServerInfo(greeting, capabilities, accountId);
         } catch (IOException e) {
