@@ -564,7 +564,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
      * @param examineHasAttachmentUserFlags Whether has-attachment user flags should be considered
      * @return The resulting mail message
      * @throws MessagingException If a messaging error occurs
-     * @throws OXException If an OX error occurs
+     * @throws OXException If an Open-Xchange error occurs
      */
     public static MailMessage handleFetchRespone(FetchResponse fetchResponse, String fullName, int accountId, boolean examineHasAttachmentUserFlags) throws MessagingException, OXException {
         IDMailMessage mail = new IDMailMessage(null, fullName);
@@ -581,7 +581,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
      * @param examineHasAttachmentUserFlags Whether has-attachment user flags should be considered
      * @return The resulting mail message
      * @throws MessagingException If a messaging error occurs
-     * @throws OXException If an OX error occurs
+     * @throws OXException If an Open-Xchange error occurs
      */
     public static MailMessage handleFetchRespone(IDMailMessage mail, FetchResponse fetchResponse, String fullName, boolean examineHasAttachmentUserFlags) throws MessagingException, OXException {
         return handleFetchRespone(mail, fetchResponse, fullName, null, false, false, false, false, examineHasAttachmentUserFlags);
@@ -594,6 +594,14 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
     }
 
     private static MailMessage handleFetchRespone(IDMailMessage mail, FetchResponse fetchResponse, String fullName, Set<FetchItemHandler> lastHandlers, boolean determineAttachmentByHeader, boolean checkICal, boolean checkVCard, boolean treatEmbeddedAsAttachment, boolean examineHasAttachmentUserFlags) throws MessagingException, OXException {
+        try {
+            return doHandleFetchRespone(mail, fetchResponse, fullName, lastHandlers, determineAttachmentByHeader, checkICal, checkVCard, treatEmbeddedAsAttachment, examineHasAttachmentUserFlags);
+        } catch (RuntimeException e) {
+            throw MailExceptionCode.UNEXPECTED_ERROR.create(e, e.getMessage());
+        }
+    }
+
+    private static MailMessage doHandleFetchRespone(IDMailMessage mail, FetchResponse fetchResponse, String fullName, Set<FetchItemHandler> lastHandlers, boolean determineAttachmentByHeader, boolean checkICal, boolean checkVCard, boolean treatEmbeddedAsAttachment, boolean examineHasAttachmentUserFlags) throws MessagingException, OXException {
         IDMailMessage m;
         if (null == mail) {
             m = new IDMailMessage(null, fullName);
@@ -651,7 +659,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
             }
         }
 
-        // Drop possible set "com.openexchange.mail.mailId" log property
+        // Drop possibly set "com.openexchange.mail.mailId" log property
         LogProperties.remove(LogProperties.Name.MAIL_MAIL_ID);
 
         return m;
@@ -1047,10 +1055,19 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
             msg.addReplyTo(wrap(env.replyTo));
             msg.setHeader("In-Reply-To", env.inReplyTo);
             msg.setHeader("Message-Id", env.messageId);
-            msg.setSubject(MimeMessageUtility.decodeEnvelopeSubject(env.subject), true);
+            msg.setSubject(decodeSubject(env.subject), true);
             msg.setSentDate(env.date);
         }
 
+        private String decodeSubject(String envelopeSubject) {
+            try {
+                return MimeMessageUtility.decodeEnvelopeSubject(envelopeSubject);
+            } catch (Exception e) {
+                LOG.warn("Failed to decode subject from ENVELOPE fetch item: `{}\u00b4. Using raw one instead.", envelopeSubject, e);
+                return envelopeSubject;
+            }
+        }
+
         private InternetAddress[] wrap(InternetAddress... addresses) {
             if (null == addresses || 0 == addresses.length) {
                 return null;
