@@ -67,6 +67,7 @@ import com.openexchange.imap.cache.RightsCache;
 import com.openexchange.imap.config.IMAPConfig;
 import com.openexchange.imap.ping.IMAPCapabilityAndGreetingCache;
 import com.openexchange.imap.util.HostAndPort;
+import com.openexchange.mailaccount.MailAccount;
 import com.sun.mail.imap.ACL;
 import com.sun.mail.imap.IMAPFolder;
 import com.sun.mail.imap.IMAPStore;
@@ -128,13 +129,13 @@ public final class Entity2ACLAutoDetector {
         }
         try {
             return cached.get();
-        } catch (final InterruptedException e) {
+        } catch (InterruptedException e) {
             // Keep interrupted status
             Thread.currentThread().interrupt();
             throw new IOException(e.getMessage());
-        } catch (final CancellationException e) {
+        } catch (CancellationException e) {
             throw new IOException(e.getMessage());
-        } catch (final ExecutionException e) {
+        } catch (ExecutionException e) {
             final Throwable cause = e.getCause();
             if (cause instanceof OXException) {
                 throw ((OXException) cause);
@@ -165,7 +166,8 @@ public final class Entity2ACLAutoDetector {
 
         @Override
         public Entity2ACL call() throws Exception {
-            final String greeting = IMAPCapabilityAndGreetingCache.getGreeting(HostAndPort.instanceFor(serverUrl), imapConfig.isSecure(), imapConfig.getIMAPProperties());
+            boolean isPrimary = imapConfig.getAccountId() == MailAccount.DEFAULT_ID;
+            String greeting = IMAPCapabilityAndGreetingCache.getGreeting(HostAndPort.instanceFor(serverUrl), imapConfig.isSecure(), imapConfig.getIMAPProperties(), isPrimary);
             return implFor(greeting, imapConfig);
         }
 
@@ -222,7 +224,7 @@ public final class Entity2ACLAutoDetector {
         final InetSocketAddress socketAddress;
         try {
             socketAddress = imapConfig.getImapServerSocketAddress();
-        } catch (final IMAPException e) {
+        } catch (IMAPException e) {
             throw Entity2ACLExceptionCode.UNKNOWN_IMAP_SERVER.create(e, info);
         }
         IMAPServer imapServer = CACHE.get(socketAddress);
@@ -259,10 +261,10 @@ public final class Entity2ACLAutoDetector {
                 }
                 CACHE.put(socketAddress, IMAPServer.UNKNOWN);
                 throw Entity2ACLExceptionCode.UNKNOWN_IMAP_SERVER.create(info);
-            } catch (final MessagingException e) {
+            } catch (MessagingException e) {
                 CACHE.put(socketAddress, IMAPServer.UNKNOWN);
                 throw Entity2ACLExceptionCode.UNKNOWN_IMAP_SERVER.create(e, info);
-            } catch (final RuntimeException e) {
+            } catch (RuntimeException e) {
                 CACHE.put(socketAddress, IMAPServer.UNKNOWN);
                 throw Entity2ACLExceptionCode.UNKNOWN_IMAP_SERVER.create(e, info);
             }
