@@ -198,7 +198,7 @@ public final class IMAPStoreCache {
         public void run() {
             try {
                 storeCache.closeElapsed();
-            } catch (final Exception e) {
+            } catch (Exception e) {
                 LOG.error("", e);
             }
         }
